@@ -1,7 +1,5 @@
 import logging
 
-import psycopg2
-
 from pyametista.engine.bands.elements import add_attr2attributes
 from pyametista.engine.components.components import process_componentElement
 from pyametista.engine.components.image import process_image
@@ -10,6 +8,9 @@ from pyametista.engine.components.shapes import process_circle, process_ellipse,
 from pyametista.engine.components.text import process_static_text, process_text_field
 from pyametista.exports.pdf import create_canvas, write_to_file
 
+# import psycopg2
+
+
 logger = logging.getLogger(__name__)
 
 
